<?php
namespace DaReactions\Pages;
use DaReactions\Options;
use \Closure;
class SettingsPage {
	/**
	 * @var Options $options
	 * The Options instance to manage page settings
	 *
	 * @since 1.0.0
	 */
	protected $options;
	/**
	 * @var string $options_group
	 * The name of the group for saved options
	 *
	 * @since 1.0.0
	 */
	protected $options_group;
	/**
	 * @var string $options_page
	 * The slug of the settings page in wich the options are managed
	 *
	 * @since 1.0.0
	 */
	protected $options_page;
	/**
	 * Page constructor.
	 *
	 * @param string $options_group
	 * @param string $section
	 *
	 * @since 1.0.0
	 */
	public function __construct( string $options_group, string $section) {
		$this->options_group = $options_group . '_' . $section;
		$this->options_page  = $options_group . '_' . $section . '_page';
		$this->options       = Options::getInstance( $section );
	}
	/**
	 * Renders the main form for this page
	 *
	 * @since 1.0.0
	 */
	public function displayPage() {
		?>
		<form action="<?= 'options.php' ?>" method='post'>
			<?php
			settings_fields( $this->options_group );
			do_settings_sections( $this->options_page );
			submit_button();
			?>
		</form>
		<?php
	}
	/**
	 * Return generic checkbox render function
	 *
	 * @param $field_id
	 * @param $message
	 * @param array $attributes
	 *
	 * @return Closure
	 */
	public function makeCheckboxRenderer( $field_id, $message, $attributes = array() ) {
		return function () use ( $field_id, $message, $attributes ) {
			$field_name  = $this->options->getFieldName( $field_id );
			$saved_value = $this->options->getOption( $field_id );
			$checked     = isset( $saved_value ) && $saved_value == 'on';
			$additional_attributes = '';
			foreach ( $attributes as $key => $value ) {
				$additional_attributes .= ' ' . $key . '="' . $value . '"';
			}
			?>
			<p>
				<input
					type="hidden"
					name="<?= $field_name ?>"
					value="off"/>
				<input id="id_<?= $field_name ?>" type="checkbox"
				       name="<?= $field_name ?>" <?php checked( $checked, 1 ) ?>
					<?= $additional_attributes ?>
					   value="on"/>
				<label for="id_<?= $field_name ?>"><?= $message; ?></label>
			</p>
			<?php
		};
	}
	/**
	 * Return generic section render function
	 *
	 * @param $message
	 *
	 * @param string $tab_menu
	 *
	 * @return \Closure
	 *
	 * @since 3.1.1
	 */
	public function makeSectionRenderer( $message, $tab_menu = '' ) {
		return function () use ( $message, $tab_menu ) {
		    echo $tab_menu;
			echo "<p>$message</p>";
			echo '<hr>';
		};
	}
	/**
	 * Return generic select field render function
	 *
	 * @param $field_id
	 * @param $default
	 * @param $options
	 * @param array $attributes
	 *
	 * @return \Closure
	 */
	public function makeSelectRenderer( $field_id, $default, $options, $attributes = array() ) {
		return function () use ( $field_id, $default, $options, $attributes ) {
			$field_name  = $this->options->getFieldName( $field_id );
			$saved_value = $this->options->getOption( $field_id, $default );
			$additional_attributes = '';
			foreach ( $attributes as $key => $value ) {
				$additional_attributes .= ' ' . $key . '="' . $value . '"';
			}
			?>
            <p>
            <select
                    name="<?= $field_name; ?>"
				<?= $additional_attributes; ?>>
				<?php foreach ( $options as $key => $value ) { ?>
                    <option
                            value="<?= $key ?>" <?= ( $saved_value === $key ? 'selected' : '' ); ?>>
						<?= $value; ?>
                    </option>
				<?php } ?>
            </select>
			<?php
		};
	}
	/**
	 * Return generic input field render function
	 *
	 * @param $field_id
	 * @param $default
	 * @param array $attributes
	 *
	 * @return Closure
	 */
	public function makeTextfieldRenderer( $field_id, $default, $attributes = array() ) {
		return function () use ( $field_id, $default, $attributes ) {
			$field_name  = $this->options->getFieldName( $field_id );
			$saved_value = $this->options->getOption( $field_id, $default );
			$additional_attributes = '';
			foreach ( $attributes as $key => $value ) {
				$additional_attributes .= ' ' . $key . '="' . $value . '"';
			}
			?>
            <p>
                <input
                        id="id_<?= $field_name ?>"
					<?= $additional_attributes ?>
                        name="<?= $field_name ?>"
                        value="<?= $saved_value ?>"/>
            </p>
			<?php
		};
	}
}
